'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var propTypes = require('prop-types');
var withForwardedRef = _interopDefault(require('react-with-forwarded-ref'));

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _inherits(subClass, superClass) {
  if (typeof superClass !== "function" && superClass !== null) {
    throw new TypeError("Super expression must either be null or a function");
  }

  subClass.prototype = Object.create(superClass && superClass.prototype, {
    constructor: {
      value: subClass,
      writable: true,
      configurable: true
    }
  });
  if (superClass) _setPrototypeOf(subClass, superClass);
}

function _getPrototypeOf(o) {
  _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
    return o.__proto__ || Object.getPrototypeOf(o);
  };
  return _getPrototypeOf(o);
}

function _setPrototypeOf(o, p) {
  _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
    o.__proto__ = p;
    return o;
  };

  return _setPrototypeOf(o, p);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _assertThisInitialized(self) {
  if (self === void 0) {
    throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
  }

  return self;
}

function _possibleConstructorReturn(self, call) {
  if (call && (typeof call === "object" || typeof call === "function")) {
    return call;
  }

  return _assertThisInitialized(self);
}

var parseOffset = function parseOffset(offset) {
  if (!offset || parseFloat(offset) === 0) {
    return '0px';
  }

  return typeof offset === 'number' ? "".concat(offset, "px") : offset;
};

var getInitial = function getInitial(_ref) {
  var isOpen = _ref.isOpen,
      style = _ref.style;
  return Object.assign({}, {
    zIndex: '999'
  }, style, {
    position: 'absolute',
    top: '0',
    left: '0',
    opacity: isOpen ? '1' : '0',
    visibility: isOpen ? 'visible' : 'hidden'
  });
};

var getPCStyle = function getPCStyle(_ref2) {
  var dirBottom = _ref2.dirBottom,
      dirLeft = _ref2.dirLeft,
      dirRight = _ref2.dirRight,
      dirTop = _ref2.dirTop,
      height = _ref2.height,
      isOpen = _ref2.isOpen,
      _offset = _ref2.offset,
      style = _ref2.style,
      triggerRect = _ref2.triggerRect,
      width = _ref2.width;
  var initial = getInitial({
    isOpen: isOpen,
    style: style
  });

  if (!isOpen || !triggerRect) {
    return initial;
  }

  var offset = parseOffset(_offset);
  var realTop = window.pageYOffset + triggerRect.top;
  var realLeft = window.pageXOffset + triggerRect.left;
  var toTop = {
    top: "calc(".concat(realTop - height, "px - ").concat(offset, ")")
  };
  var toRight = {
    left: "calc(".concat(realLeft + triggerRect.width, "px + ").concat(offset, ")")
  };
  var toBottom = {
    top: "calc(".concat(realTop + triggerRect.height, "px + ").concat(offset, ")")
  };
  var toLeft = {
    left: "calc(".concat(realLeft - width, "px - ").concat(offset, ")")
  };
  var toMiddleX = {
    left: "".concat(realLeft + triggerRect.width / 2 - width / 2, "px")
  };
  var toMiddleY = {
    top: "".concat(realTop + triggerRect.height / 2 - height / 2, "px")
  };
  var isOutsideTop = triggerRect.top - height <= 0;
  var isOutsideRight = triggerRect.left + width >= window.innerWidth;
  var isOutsideBottom = triggerRect.top + triggerRect.height + height >= window.innerHeight;
  var isOutsideLeft = triggerRect.left - width <= 0;
  return Object.assign({}, initial, toBottom, // default
  toMiddleX, // default
  dirTop && toTop, dirRight && toRight, dirBottom && toBottom, dirLeft && toLeft, (dirTop || dirBottom) && !dirLeft && !dirRight && toMiddleX, (dirRight || dirLeft) && !dirTop && !dirBottom && toMiddleY, dirTop && isOutsideTop && toBottom, dirRight && isOutsideRight && toLeft, dirBottom && isOutsideBottom && toTop, dirLeft && isOutsideLeft && toRight);
};

var PopoverContent =
/*#__PURE__*/
function (_Component) {
  _inherits(PopoverContent, _Component);

  function PopoverContent() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, PopoverContent);

    for (var _len = arguments.length, params = new Array(_len), _key = 0; _key < _len; _key++) {
      params[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(PopoverContent)).call.apply(_getPrototypeOf2, [this].concat(params)));
    _this.state = {
      height: 0,
      width: 0
    };
    return _this;
  }

  _createClass(PopoverContent, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.setDimensions();
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var _this2 = this;

      this.setDimensions();
      setTimeout(function () {
        var _this2$props = _this2.props,
            forwardedRef = _this2$props.forwardedRef,
            isOpen = _this2$props.isOpen;

        if (!prevProps.isOpen && isOpen && forwardedRef && forwardedRef.current) {
          forwardedRef.current.focus();
        }
      }, 0);
    }
  }, {
    key: "setDimensions",
    value: function setDimensions() {
      var current = this.props.forwardedRef.current,
          _this$state = this.state,
          height = _this$state.height,
          width = _this$state.width;

      if (height !== current.offsetHeight || width !== current.offsetWidth) {
        this.setState({
          height: current.offsetHeight,
          width: current.offsetWidth
        });
      }
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props = this.props,
          dirBottom = _this$props.bottom,
          children = _this$props.children,
          forwardedRef = _this$props.forwardedRef,
          id = _this$props.id,
          isOpen = _this$props.isOpen,
          label = _this$props.label,
          dirLeft = _this$props.left,
          offset = _this$props.offset,
          dirRight = _this$props.right,
          style = _this$props.style,
          dirTop = _this$props.top,
          triggerRect = _this$props.triggerRect,
          rest = _objectWithoutProperties(_this$props, ["bottom", "children", "forwardedRef", "id", "isOpen", "label", "left", "offset", "right", "style", "top", "triggerRect"]),
          _this$state2 = this.state,
          height = _this$state2.height,
          width = _this$state2.width;

      var newStyle = getPCStyle({
        dirBottom: dirBottom,
        dirLeft: dirLeft,
        dirRight: dirRight,
        dirTop: dirTop,
        height: height,
        isOpen: isOpen,
        offset: offset,
        style: style,
        triggerRect: triggerRect,
        width: width
      });
      return React__default.createElement("div", _extends({}, rest, {
        "aria-hidden": !isOpen,
        "aria-label": label,
        id: id,
        ref: forwardedRef,
        role: "dialog",
        style: newStyle,
        tabIndex: "-1"
      }), children);
    }
  }]);

  return PopoverContent;
}(React.Component);
PopoverContent.propTypes = {
  bottom: propTypes.bool,
  children: propTypes.node,
  forwardedRef: propTypes.shape({
    current: propTypes.shape({
      focus: propTypes.func
    })
  }),
  id: propTypes.string.isRequired,
  isOpen: propTypes.bool,
  label: propTypes.string,
  left: propTypes.bool,
  offset: propTypes.oneOfType([propTypes.number, propTypes.string]),
  right: propTypes.bool,
  style: propTypes.object,
  top: propTypes.bool,
  triggerRect: propTypes.object
};
var PopoverContent$1 = withForwardedRef(PopoverContent);

exports.PopoverContent = PopoverContent;
exports.PopoverContent$1 = PopoverContent$1;
exports._assertThisInitialized = _assertThisInitialized;
exports._classCallCheck = _classCallCheck;
exports._createClass = _createClass;
exports._extends = _extends;
exports._getPrototypeOf = _getPrototypeOf;
exports._inherits = _inherits;
exports._possibleConstructorReturn = _possibleConstructorReturn;
//# sourceMappingURL=PopoverContent-aa156b5f.js.map
