import { _ as _inherits, b as _createClass, c as _classCallCheck, d as _possibleConstructorReturn, e as _getPrototypeOf, f as _assertThisInitialized, g as _extends, a as PopoverContent } from './PopoverContent-f4fcbeca.js';
import React, { createRef, cloneElement, PureComponent } from 'react';
import { createPortal } from 'react-dom';
import ButtonA11y from 'react-button-a11y';
import uniqueId from '@rpearce/simple-uniqueid';
import { bool, node, string, oneOfType, number, func } from 'prop-types';
import 'react-with-forwarded-ref';

var throttle = function throttle(callback, limit) {
  var wait = false;
  return function () {
    if (!wait) {
      callback.call();
      wait = true;
      setTimeout(function () {
        wait = false;
      }, limit);
    }
  };
};

var Popover =
/*#__PURE__*/
function (_PureComponent) {
  _inherits(Popover, _PureComponent);

  function Popover() {
    var _getPrototypeOf2;

    var _this;

    _classCallCheck(this, Popover);

    for (var _len = arguments.length, params = new Array(_len), _key = 0; _key < _len; _key++) {
      params[_key] = arguments[_key];
    }

    _this = _possibleConstructorReturn(this, (_getPrototypeOf2 = _getPrototypeOf(Popover)).call.apply(_getPrototypeOf2, [this].concat(params)));
    _this.handleClickTrigger = _this.handleClickTrigger.bind(_assertThisInitialized(_this));
    _this.handleDocumentClick = _this.handleDocumentClick.bind(_assertThisInitialized(_this));
    _this.handleKeyDown = _this.handleKeyDown.bind(_assertThisInitialized(_this));
    _this.handleResize = throttle(_this.handleResize.bind(_assertThisInitialized(_this)), 50);
    _this.el = document.createElement('div');
    _this.id = uniqueId('popover-');
    _this.triggerRef = createRef();
    _this.popoverRef = createRef();
    return _this;
  }

  _createClass(Popover, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      document.body.appendChild(this.el);
    }
  }, {
    key: "componentDidUpdate",
    value: function componentDidUpdate(prevProps) {
      var isOpen = this.props.isOpen;

      if (prevProps.isOpen && !isOpen) {
        this.teardown();
      } else if (!prevProps.isOpen && isOpen) {
        this.setup();
      }
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      var isOpen = this.props.isOpen;

      if (isOpen) {
        this.teardown();
      }

      document.body.removeChild(this.el);
    }
  }, {
    key: "getTriggerRect",
    value: function getTriggerRect() {
      var tNode = this.triggerRef.current;

      if (tNode) {
        var rect = tNode.getBoundingClientRect();
        return {
          height: rect.height,
          left: rect.left,
          top: rect.top,
          width: rect.width
        };
      }

      return {
        height: 0,
        left: 0,
        top: 0,
        width: 0
      };
    }
  }, {
    key: "handleClickTrigger",
    value: function handleClickTrigger() {
      var _this$props = this.props,
          isOpen = _this$props.isOpen,
          onClose = _this$props.onClose,
          onOpen = _this$props.onOpen;

      if (isOpen) {
        onClose();
        return;
      }

      onOpen();
    }
  }, {
    key: "handleDocumentClick",
    value: function handleDocumentClick(e) {
      var isTrigger = this.triggerRef.current.contains(e.target);
      var isPopover = this.popoverRef.current.contains(e.target);

      if (isTrigger || isPopover) {
        return;
      }

      this.props.onClose();
    }
  }, {
    key: "handleKeyDown",
    value: function handleKeyDown(e) {
      if (e.key === 'Escape' || e.keyCode === 27) {
        this.triggerRef.current.focus();
        this.props.onClose();
      }
    }
  }, {
    key: "handleResize",
    value: function handleResize() {
      this.forceUpdate();
    }
  }, {
    key: "setup",
    value: function setup() {
      document.addEventListener('click', this.handleDocumentClick);
      document.addEventListener('keydown', this.handleKeyDown);
      window.addEventListener('resize', this.handleResize);
    }
  }, {
    key: "teardown",
    value: function teardown() {
      window.removeEventListener('resize', this.handleResize);
      document.removeEventListener('keydown', this.handleKeyDown);
      document.removeEventListener('click', this.handleDocumentClick);
    }
  }, {
    key: "renderTrigger",
    value: function renderTrigger() {
      var _this$props2 = this.props,
          isOpen = _this$props2.isOpen,
          label = _this$props2.label,
          _this$props2$trigger = _this$props2.trigger,
          props = _this$props2$trigger.props,
          type = _this$props2$trigger.type;
      return React.createElement(ButtonA11y, _extends({}, props, {
        "aria-controls": this.id,
        "aria-expanded": isOpen,
        "aria-haspopup": true,
        "aria-label": label,
        "aria-owns": this.id,
        onClick: this.handleClickTrigger,
        element: type,
        ref: this.triggerRef
      }));
    }
  }, {
    key: "renderPopover",
    value: function renderPopover() {
      var _this$props3 = this.props,
          bottom = _this$props3.bottom,
          content = _this$props3.content,
          isOpen = _this$props3.isOpen,
          label = _this$props3.label,
          left = _this$props3.left,
          offset = _this$props3.offset,
          right = _this$props3.right,
          top = _this$props3.top;
      var cProps = {
        bottom: bottom,
        id: this.id,
        isOpen: isOpen,
        label: label,
        left: left,
        offset: offset,
        ref: this.popoverRef,
        right: right,
        top: top,
        triggerRect: this.getTriggerRect()
      };

      if (content.type === PopoverContent) {
        return cloneElement(content, cProps);
      }

      return React.createElement(PopoverContent, cProps, content);
    }
  }, {
    key: "render",
    value: function render() {
      return React.createElement("span", null, this.renderTrigger(), createPortal(this.renderPopover(), this.el));
    }
  }]);

  return Popover;
}(PureComponent);
Popover.propTypes = {
  bottom: bool,
  content: node,
  isOpen: bool,
  label: string,
  left: bool,
  offset: oneOfType([number, string]),
  onClose: func,
  onOpen: func,
  right: bool,
  top: bool,
  trigger: node
};

export default Popover;
//# sourceMappingURL=Popover.js.map
